@@ -331,9 +331,12 @@ my %_DEFAULTS = (
         [% NEXT IF !profiles.$profile.exists('total') -%]
         [% NEXT IF profiles.$profile.total <= 0 -%]
         [% profile %]: [% profiles.$profile.total %] - [% contacts.$profile.join(', ') %]
-        [% FOREACH month IN profiles.$profile.keys.sort -%]
-            [%- NEXT IF month == "total" -%]
-            [% month %]: [% profiles.$profile.$month %]
+        [% FOREACH date IN profiles.$profile.keys.sort -%]
+            [%- NEXT IF date == "total" -%]
+            [% date %]: [% profiles.$profile.$date.size %]
+            [% FOREACH commit IN profiles.$profile.$date -%]
+               - [% commit.sha1 %]
+            [% END -%]
         [% END %]
         [% END -%]
 
@@ -400,7 +403,7 @@ Git::Code::Review::Notify - Notification framework
 
 =head1 VERSION
 
-version 1.9
+version 2.0
 
 =head1 AUTHOR
 
