@@ -3,7 +3,7 @@ package Git::Code::Review::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '1.9'; # VERSION
+our $VERSION = '2.0'; # VERSION
 
 # Utility Modules
 use CLI::Helpers qw(:all);
@@ -740,7 +740,7 @@ sub _get_commit_date {
     while( !$ISO ) {
         local $_ = <$fh>;
         last unless defined $_;
-        next unless /^Date:/;
+        next unless /^(Commit)Date:/;
         $ISO = (split /\s+/)[1];
     }
     return $ISO;
@@ -832,7 +832,7 @@ Git::Code::Review::Utilities - Tools for performing code review using Git as the
 
 =head1 VERSION
 
-version 1.9
+version 2.0
 
 =head1 FUNCTIONS
 
